import { fetch, post } from '@api/api';

/**
 * 查询Tenant
 * @param params 请求参数
 * @param headers 请求头
 */
export function fetchTenantPage(params = {}, headers = {}) {
  return fetch({
    url: '/upms/tenant/page',
    params: params,
    headers: headers
  });
}

/**
 * 查询单个Tenant
 * @param params 请求参数
 * @param headers 请求头
 */
export function fetchTenantById(params = {}, headers = {}) {
  return fetch({
    url: '/upms/tenant/by-id',
    params: params,
    headers: headers
  });
}

/**
 * 新增Tenant
 * @param params 请求参数
 * @param headers 请求头
 */
export function createTenant(params = {}, headers = {}) {
  return post({
    url: '/upms/tenant/create',
    params: params,
    headers: headers
  });
}

/**
 * 更新Tenant
 * @param params 请求参数
 * @param headers 请求头
 */
export function updateTenant(params = {}, headers = {}) {
  return post({
    url: '/upms/tenant/update',
    params: params,
    headers: headers
  });
}

/**
 * 删除Tenant
 * @param params 请求参数
 * @param headers 请求头
 */
export function removeTenant(params = {}, headers = {}) {
  return post({
    url: '/upms/tenant/remove',
    params: params,
    headers: headers
  });
}
/**
 * 删除Tenant
 * @param params 请求参数
 * @param headers 请求头
 */
export function syncTenantMenu(params = {}, headers = {}) {
  return post({
    url: '/upms/tenant/menu/sync',
    params: params,
    headers: headers
  });
}
